@@ -105,6 +105,7 @@ class HyASTCompiler(object):
         expr.pop(0)  # try
 
         if sys.version_info[0] >= 3 and sys.version_info[1] >= 3:
+            # Python 3.3 features a rename of TryExcept to Try.
             Try = ast.Try
         else:
             Try = ast.TryExcept
@@ -120,12 +121,27 @@ class HyASTCompiler(object):
     @builds("catch")
     def compile_catch_expression(self, expr):
         expr.pop(0)  # catch
+        _type = self.compile(expr.pop(0))
+        name = expr.pop(0)
+
+        if sys.version_info[0] >= 3:
+            # Python3 features a change where the Exception handler
+            # moved the name from a Name() to a pure Python String type.
+            #
+            # We'll just make sure it's a pure "string", and let it work
+            # it's magic.
+            name = str(name)
+        else:
+            # Python2 requires an ast.Name, set to ctx Store.
+            name = self.compile(name)
+            name.ctx = ast.Store()
+
         return ast.ExceptHandler(
             lineno=expr.start_line,
             col_offset=expr.start_column,
-            type=self.compile(expr.pop(0)),
-            name=None,
-            body=self._code_branch(self.compile(expr.pop(0))))
+            type=_type,
+            name=name,
+            body=self._code_branch([self.compile(x) for x in expr]))
 
     def _code_branch(self, branch):
         if isinstance(branch, list):
@@ -188,6 +204,18 @@ class HyASTCompiler(object):
                 kw_defaults=[]),
             body=self.compile(body))
 
+    @builds("pass")
+    def compile_pass_expression(self, expr):
+        return ast.Pass(lineno=expr.start_line, col_offset=expr.start_column)
+
+    @builds("yield")
+    def compile_yield_expression(self, expr):
+        expr.pop(0)
+        return ast.Yield(
+            value=self.compile(expr.pop(0)),
+            lineno=expr.start_line,
+            col_offset=expr.start_column)
+
     @builds("import")
     def compile_import_expression(self, expr):
         expr.pop(0)  # index
@@ -359,6 +387,7 @@ class HyASTCompiler(object):
                         col_offset=expression.start_column)
 
     @builds("def")
+    @builds("set")
     def compile_def_expression(self, expression):
         expression.pop(0)  # "def"
         name = expression.pop(0)
@@ -380,7 +409,7 @@ class HyASTCompiler(object):
             col_offset=expression.start_column,
             targets=[name], value=what)
 
-    @builds("for")
+    @builds("foreach")
     def compile_for_expression(self, expression):
         ret_status = self.returnable
         self.returnable = False
@@ -465,7 +494,9 @@ class HyASTCompiler(object):
                 ctx=ast.Load()
             )
 
-        return ast.Name(id=str(symbol), ctx=ast.Load(),
+        return ast.Name(id=str(symbol),
+                        arg=str(symbol),
+                        ctx=ast.Load(),
                         lineno=symbol.start_line,
                         col_offset=symbol.start_column)
 
@@ -489,8 +520,11 @@ class HyASTCompiler(object):
             values=vals)
 
 
-def hy_compile(tree):
+def hy_compile(tree, root=None):
     " Compile a HyObject tree into a Python AST tree. "
     compiler = HyASTCompiler()
-    ret = ast.Module(body=compiler._mangle_branch(compiler.compile(tree)))
+    tlo = root
+    if root is None:
+        tlo = ast.Module
+    ret = tlo(body=compiler._mangle_branch(compiler.compile(tree)))
     return ret
