@@ -61,6 +61,9 @@ def _resolve_atom(obj):
     if obj in table:
         return HySymbol(table[obj])
 
+    if obj.startswith("*") and obj.endswith("*") and obj != "*":
+        obj = obj[1:-1].upper()
+
     if "-" in obj and obj != "-":
         obj = obj.replace("-", "_")
 
@@ -150,6 +153,11 @@ class ListeyThing(State):
             self.machine.sub(String)
             return
 
+        if char == ";":
+            self.commit()
+            self.machine.sub(Comment)
+            return
+
         if char == self.end_char:
             return Idle
 
@@ -254,12 +262,18 @@ class Idle(State):
         if char == "(":
             return Expression
 
+        if char == "[":
+            return List
+
         if char == "{":
             return Dict
 
         if char == ";":
             return Comment
 
+        if char == "#":
+            return Hash
+
         if char in WHITESPACE:
             return
 
@@ -281,3 +295,21 @@ class Comment(State):
 
         if char == "\n":
             return Idle
+
+
+class Hash(State):
+    """
+    Hash state
+    """
+
+    def process(self, char):
+        """
+        State transitions:
+
+            - ! - Comment
+        """
+
+        if char == "!":
+            return Comment
+
+        raise LexException("Unknown char (Hash state): `%s`" % (char))
